<?php
/**
 * Abstract WordPress Blog Theme functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Abstract_WordPress_Blog_Theme
 */

if ( ! function_exists( 'abstractblogtheme_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function abstractblogtheme_setup() {
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Abstract WordPress Blog Theme, use a find and replace
	 * to change 'abstractblogtheme' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'abstractblogtheme', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support( 'post-thumbnails' );
        set_post_thumbnail_size(277, 395, TRUE);

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => esc_html__( 'Primary', 'abstractblogtheme' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'abstractblogtheme_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );
        
        add_theme_support( 'post-formats', array(
		'aside',
		'image',
		'video',
		'quote',
		'link',
	) );
}
endif;
add_action( 'after_setup_theme', 'abstractblogtheme_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function abstractblogtheme_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'abstractblogtheme_content_width', 640 );
}
add_action( 'after_setup_theme', 'abstractblogtheme_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function abstractblogtheme_widgets_init() {
        
        register_sidebar( array(
		'name'          => esc_html__( 'Footer Column 1', 'abstractblogtheme' ),
		'id'            => 'footer-1',
		'description'   => esc_html__( 'Add widgets here.', 'abstractblogtheme' ),
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
        
        register_sidebar( array(
		'name'          => esc_html__( 'Footer Column 2', 'abstractblogtheme' ),
		'id'            => 'footer-2',
		'description'   => esc_html__( 'Add widgets here.', 'abstractblogtheme' ),
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
        
        register_sidebar( array(
		'name'          => esc_html__( 'Footer Column 3', 'abstractblogtheme' ),
		'id'            => 'footer-3',
		'description'   => esc_html__( 'Add widgets here.', 'abstractblogtheme' ),
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
        
        register_sidebar( array(
		'name'          => esc_html__( 'Footer Column 4', 'abstractblogtheme' ),
		'id'            => 'footer-4',
		'description'   => esc_html__( 'Add widgets here.', 'abstractblogtheme' ),
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
}
add_action( 'widgets_init', 'abstractblogtheme_widgets_init' );

function abstractblogtheme_excerpt_more( $more ) {
	return " …";
}
add_filter( 'excerpt_more', 'abstractblogtheme_excerpt_more' );

/**
 * Enqueue scripts and styles.
 */
function abstractblogtheme_scripts() {
	wp_enqueue_style( 'abstractblogtheme-style', get_stylesheet_uri() );
        
        wp_enqueue_script( 'abstractblogtheme-jquery', get_template_directory_uri() . '/js/jquery-2.1.3.min.js', array(), '1.0.0', true );
        
        wp_enqueue_script( 'abstractblogtheme-plugins', get_template_directory_uri() . '/js/plugins.js', array(), '1.0.0', true );
        
	wp_enqueue_script( 'abstractblogtheme-main', get_template_directory_uri() . '/js/main.js', array(), '1.0.0', true );

	wp_enqueue_script( 'abstractblogtheme-modernizr', get_template_directory_uri() . '/js/modernizr.js', array(), '1.0.0', true );
        
        wp_enqueue_script( 'abstractblogtheme-pace', get_template_directory_uri() . '/js/pace.min.js', array(), '1.0.0', true );
        

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'abstractblogtheme_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';
